package com.shinsoft.ware.service.impl;

import com.shinsoft.ware.model.Auto;
import com.shinsoft.ware.mapper.AutoMapper;
import com.shinsoft.ware.service.AutoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.shinsoft.workflowapi.model.WorkModel;
import com.shinsoft.workflowapi.service.WorkFlowService;
import com.shinsoft.workflowapi.util.FlowModelUtil;
import org.springframework.stereotype.Service;


import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.TypeReference;
import com.shinsoft.tools.JSONTools;
import com.shinsoft.tools.model.common.ResultJSON;
import org.apache.commons.lang3.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author system
 * @since 2024-08-29
 */
@Service
public class AutoServiceImp extends ServiceImpl<AutoMapper, Auto> implements AutoService {

    ResultJSON resultJSON;

    @Autowired
    AutoMapper autoMapper;

    @Autowired
    WorkFlowService workFlowService;

    @Override
    public ResultJSON query(int page, int rows, String params) {
        JSONObject jsonObject = JSON.parseObject(params);
        Date birthDate = jsonObject.getDate("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");
        Date addTimeBegin = addTimeRange.getDate(0);
        Date addTimeEnd = addTimeRange.getDate(1);
        Page<Auto> autoPage = new Page<>(page, rows);
        QueryWrapper<Auto> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");
        queryWrapper.eq(ObjectUtils.isNotEmpty(birthDate), "BIRTH_DATE", birthDate);
        queryWrapper.eq(StringUtils.isNotEmpty(type), "TYPE", type);
        queryWrapper.like(StringUtils.isNotEmpty(code), "CODE", code);
        queryWrapper.eq(StringUtils.isNotEmpty(name), "NAME", name);
        queryWrapper.between(ObjectUtils.isNotEmpty(addTimeBegin), "ADD_TIME", addTimeBegin, addTimeEnd);
        queryWrapper.orderByDesc("add_time");
        IPage<Auto> list = autoMapper.selectPage(autoPage, queryWrapper);

//        list.setRecords(workFlowService.bizEnhanceFlows(list.getRecords()));

//        list.getRecords().forEach(record -> {
//            record.setWorkModel(workFlowService.getWorkInfo(record.getWorkId(), record.getTrackId()));
//        });

        // 状态  驳回  生效
        // 打印接口

        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON queryByPK(String id) {
        Auto auto = autoMapper.selectByPK(id);
        resultJSON = JSONTools.toResultJSON(auto);
        return resultJSON;
    }


    @Override
    public ResultJSON save(String userId, String json) {
        Date date = new Date();
        Auto auto = JSON.parseObject(json, new TypeReference<Auto>() {
        });
        if (StringUtils.isEmpty(auto.getId())) {
            auto.setCancelFlag("0");
            auto.setAddId(userId);
            auto.setAddTime(date);
            autoMapper.insert(auto);
        } else {
            auto.setModifyId(userId);
            auto.setModifyTime(date);
            autoMapper.updateById(auto);
        }

        resultJSON = JSONTools.toResultJSON(auto);
        return resultJSON;
    }

    @Override
    public ResultJSON remove(String userId, String id) {
        Date date = new Date();
        Auto auto = autoMapper.selectById(id);
        auto.setCancelFlag("1");
        auto.setCancelId(userId);
        auto.setCancelTime(date);
        autoMapper.updateById(auto);
        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }

    @Override
    public ResultJSON removeBatch(String userId, String ids) {
        Date date = new Date();
        List<String> list = JSON.parseObject(ids, new TypeReference<List<String>>() {
        });
        Auto auto;
        for (String id : list) {
            auto = autoMapper.selectById(id);
            auto.setCancelFlag("1");
            auto.setCancelId(userId);
            auto.setCancelTime(date);
            autoMapper.updateById(auto);
        }
        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }

}
