package com.shinsoft.ware.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shinsoft.ware.mapper.AutoMapper;
import com.shinsoft.ware.model.Auto;
import com.shinsoft.ware.service.DataPermissionService;
import com.shinsoft.frameworkapi.model.Permission;
import com.shinsoft.frameworkapi.service.FrameworkService;
import com.shinsoft.tools.JSONTools;
import com.shinsoft.tools.model.common.ResultJSON;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class DataPermissionServiceImpl implements DataPermissionService {

    @Autowired
    AutoMapper autoMapper;

    @Autowired
    FrameworkService frameworkService;


    ResultJSON resultJSON;


    @Override
    public ResultJSON query(int page, int rows, String userId, String menuId, String params) {
        JSONObject jsonObject = JSON.parseObject(params);

        //获取权限
        resultJSON = frameworkService.queryDataPermission(userId, menuId);
        if (resultJSON.getCode() != 0) {
            return resultJSON;
        }
        Permission permission = JSONTools.objectToModel(resultJSON.getData(), Permission.class);
        String flag = permission.getFlag();//1为个人数据  2、3为部门数据
        List<String> deptCodes = permission.getDeptCodes();


        //表达式方式
        Page<Auto> autoPage = new Page<>(page, rows);
        QueryWrapper<Auto> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");

        if (flag.equals("1")) {
            queryWrapper.eq("add_id", userId);
        } else {
            queryWrapper.and(w -> {
                for (String deptcode : deptCodes) {
                    w.or().likeRight("add_dept_code", deptcode);
                }
            });
        }

        queryWrapper.orderByDesc("add_time");
         Page<Auto> list = autoMapper.selectPage(autoPage, queryWrapper);
        resultJSON = JSONTools.toResultJSON(list);


        //xml方式 参数
        Page<Auto> listXml = autoMapper.selectPageXml(autoPage,userId, flag ,deptCodes);
        resultJSON = JSONTools.toResultJSON(listXml);

        //xml方式 map参数
        Map<String, Object> map = new HashMap<>();
        map.put("userId", userId);
        map.put("flag", flag);
        map.put("deptCodes", deptCodes);
        Page<Auto> listMap = autoMapper.selectPageXmlMap(autoPage, map);
        resultJSON = JSONTools.toResultJSON(listMap);



        return resultJSON;
    }
}
