package com.shinsoft.ware.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.read.listener.ReadListener;
import com.alibaba.excel.util.ListUtils;
import com.shinsoft.ware.model.ExportData;
import com.shinsoft.ware.model.Imexport;
import com.shinsoft.ware.mapper.ImexportMapper;
import com.shinsoft.ware.model.ImportData;
import com.shinsoft.ware.service.ImexportService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;


import org.springframework.beans.factory.annotation.Autowired;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import java.util.List;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.TypeReference;
import com.shinsoft.tools.JSONTools;
import com.shinsoft.tools.model.common.ResultJSON;
import org.apache.commons.lang3.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.MultiValueMap;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * <p>
 * 采购订单行 服务实现类
 * </p>
 *
 * @author system
 * @since 2024-10-08
 */
@Service
public class ImexportServiceImp extends ServiceImpl<ImexportMapper, Imexport> implements ImexportService {


    ResultJSON resultJSON;

    @Autowired
    ImexportMapper imexportMapper;


    @Override
    public ResultJSON importExcel(HttpServletRequest request) throws IOException {
        //获取导入的excel文件
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        MultiValueMap<String, MultipartFile> files = multipartRequest.getMultiFileMap();
        if (ObjectUtils.isEmpty(files) || ObjectUtils.isEmpty(files.get("file")) || files.get("file").size() == 0) {
            resultJSON = JSONTools.toResultJSON("请上传文件");
            return resultJSON;
        }
        MultipartFile mf = files.get("file").get(0);
        InputStream input = mf.getInputStream();

        //获取自定义参数
        String fId = multipartRequest.getParameter("fId");

        //读取excel文件
        EasyExcel.read(input, ImportData.class, new ReadListener<ImportData>() {
            /**
             * 单次缓存的数据量
             */
            public static final int BATCH_COUNT = 100;
            /**
             *临时存储
             */
            private List<ImportData> cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);

            @Override
            public void invoke(ImportData data, AnalysisContext context) {
                cachedDataList.add(data);
                if (cachedDataList.size() >= BATCH_COUNT) {
                    saveData();
                    // 存储完成清理 list
                    cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);
                }
            }

            @Override
            public void doAfterAllAnalysed(AnalysisContext context) {
                saveData();
            }

            /**
             * 加上存储数据库
             */
            private void saveData() {
                System.out.println(cachedDataList.size() + "条数据，开始存储数据库！");
                System.out.println("存储数据库成功！");
                Date date = new Date();
                List<Imexport> list = BeanUtil.copyToList(cachedDataList, Imexport.class);
                for (Imexport imexport : list) {
                    imexport.setAddName("导入测试用户");
                    imexport.setAddTime(date);
                }
                imexportMapper.insert(list);
            }
        }).sheet().doRead();

        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }

    @Override
    public void exportExcel(String params, HttpServletRequest request, HttpServletResponse response) throws IOException {
        System.out.println("params:" + params);
        OutputStream os = null;
        response.reset();
        response.setContentType("application/octet-stream");
        response.setCharacterEncoding("utf-8");
        response.setHeader("Content-Disposition", "attachment;filename=" + new String("导出excel.xlsx".getBytes("gb2312"), "ISO8859-1"));
        os = response.getOutputStream();

        EasyExcel.write(os, ExportData.class)
                .sheet("sheet1")
                .doWrite(() -> {
                    // 分页查询数据

                    Page<Imexport> imexportPage = new Page<>(1, 50);
                    QueryWrapper<Imexport> queryWrapper = new QueryWrapper<>();
                    Page<Imexport> list = imexportMapper.selectPage(imexportPage, queryWrapper);
                    List<ExportData> resultData = BeanUtil.copyToList(list.getRecords(), ExportData.class);

                    return resultData;
                });

    }


    @Override
    public ResultJSON query(int page, int rows, String params) {

        Page<Imexport> imexportPage = new Page<>(page, rows);
        QueryWrapper<Imexport> queryWrapper = new QueryWrapper<>();
        IPage<Imexport> list = imexportMapper.selectPage(imexportPage, queryWrapper);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON queryByPK(String id) {
        Imexport imexport = imexportMapper.selectByPK(id);
        resultJSON = JSONTools.toResultJSON(imexport);
        return resultJSON;
    }


    @Override
    public ResultJSON save(String userId, String json) {
        Date date = new Date();
        Imexport imexport = JSON.parseObject(json, new TypeReference<Imexport>() {
        });
        if (StringUtils.isEmpty(imexport.getId())) {
            imexport.setCancelFlag("0");
            imexport.setAddId(userId);
            imexport.setAddTime(date);
            imexportMapper.insert(imexport);
        } else {
            imexport.setModifyId(userId);
            imexport.setModifyTime(date);
            imexportMapper.updateById(imexport);
        }

        resultJSON = JSONTools.toResultJSON(imexport);
        return resultJSON;
    }

    @Override
    public ResultJSON remove(String userId, String id) {
        Date date = new Date();
        Imexport imexport = imexportMapper.selectById(id);
        imexport.setCancelFlag("1");
        imexport.setCancelId(userId);
        imexport.setCancelTime(date);
        imexportMapper.updateById(imexport);
        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }

    @Override
    public ResultJSON removeBatch(String userId, String ids) {
        Date date = new Date();
        List<String> list = JSON.parseObject(ids, new TypeReference<List<String>>() {
        });
        Imexport imexport;
        for (String id : list) {
            imexport = imexportMapper.selectById(id);
            imexport.setCancelFlag("1");
            imexport.setCancelId(userId);
            imexport.setCancelTime(date);
            imexportMapper.updateById(imexport);
        }
        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }

    @Override
    public ResultJSON removeAll(String userId) {
        imexportMapper.deleteAll();
        resultJSON = JSONTools.toResultJSON("");
        return resultJSON;
    }


}
