package com.shinsoft.ware.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.TypeReference;
import com.shinsoft.ware.mapper.SearchSingleMapper;
import com.shinsoft.ware.model.SearchFirst;
import com.shinsoft.ware.mapper.SearchFirstMapper;
import com.shinsoft.ware.model.SearchSingle;
import com.shinsoft.ware.service.SearchService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.stereotype.Service;


import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.shinsoft.tools.JSONTools;
import com.shinsoft.tools.model.common.ResultJSON;
import org.apache.commons.lang3.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author system
 * @since 2024-08-30
 */
@Service
public class SearchServiceImp extends ServiceImpl<SearchFirstMapper, SearchFirst> implements SearchService {


    ResultJSON resultJSON;

    @Autowired
    SearchSingleMapper searchSingleMapper;

    @Override
    public ResultJSON structure(String params) {
        //解析参数
        JSONObject jsonObject = JSON.parseObject(params);
        Date birthDate = jsonObject.getDate("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");
        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (addTimeRange != null) {
            addTimeBegin = addTimeRange.getDate(0);
            addTimeEnd = addTimeRange.getDate(1);
        }


        QueryWrapper<SearchSingle> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");
        queryWrapper.eq(ObjectUtils.isNotEmpty(birthDate), "BIRTH_DATE", birthDate);
        queryWrapper.eq(StringUtils.isNotEmpty(type), "TYPE", type);
        queryWrapper.like(StringUtils.isNotEmpty(code), "CODE", code);
        queryWrapper.eq(StringUtils.isNotEmpty(name), "NAME", name);
        queryWrapper.between(ObjectUtils.isNotEmpty(addTimeBegin), "ADD_TIME", addTimeBegin, addTimeEnd);
        queryWrapper.orderByDesc("add_time");
        List<SearchSingle> list = searchSingleMapper.selectList(queryWrapper);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON annotate(String params) {
        Map<String, Object> map = JSON.parseObject(params, new TypeReference<Map<String, Object>>() {
        });
        List<SearchSingle> list = searchSingleMapper.selectByAnnotate(map);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON xml(String params) {
        //解析参数
        //解析参数
        JSONObject jsonObject = JSON.parseObject(params);
        String birth = jsonObject.getString("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");
        Date birthDate = null;
        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (addTimeRange != null) {
            String begin = addTimeRange.getString(0);
            String end = addTimeRange.getString(1);
            if (StringUtils.isNotEmpty(birth)) {
                birthDate = DateUtil.parse(birth, "yyyy-MM-dd");
            }
            if (StringUtils.isNotEmpty(begin)) {
                addTimeBegin = DateUtil.parse(begin, "yyyy-MM-dd HH:mm:ss");
            }
            if (StringUtils.isNotEmpty(end)) {
                addTimeEnd = DateUtil.parse(end, "yyyy-MM-dd HH:mm:ss");
            }
        }

        Map<String, Object> map = new HashMap<>();
        map.put("birth", birth);
        map.put("type", type);
        map.put("code", code);
        map.put("name", name);
        map.put("addTimeBegin", addTimeBegin);
        map.put("addTimeEnd", addTimeEnd);
        List<SearchSingle> list = searchSingleMapper.selectByXml(map);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON structurePage(int page, int rows, String params) {
        //解析参数
        JSONObject jsonObject = JSON.parseObject(params);
        Date birthDate = jsonObject.getDate("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");

        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (addTimeRange != null) {
            addTimeBegin = addTimeRange.getDate(0);
            addTimeEnd = addTimeRange.getDate(1);
        }


        Page<SearchSingle> autoPage = new Page<>(page, rows);
        QueryWrapper<SearchSingle> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");
        queryWrapper.eq(ObjectUtils.isNotEmpty(birthDate), "BIRTH_DATE", birthDate);
        queryWrapper.eq(StringUtils.isNotEmpty(type), "TYPE", type);
        queryWrapper.like(StringUtils.isNotEmpty(code), "CODE", code);
        queryWrapper.eq(StringUtils.isNotEmpty(name), "NAME", name);
        queryWrapper.between(ObjectUtils.isNotEmpty(addTimeBegin), "ADD_TIME", addTimeBegin, addTimeEnd);
        queryWrapper.orderByDesc("add_time");
        Page<SearchSingle> list = searchSingleMapper.selectPage(autoPage, queryWrapper);

        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON annotatePage(int page, int rows, String params) {
        Map<String, Object> map = JSON.parseObject(params, new TypeReference<Map<String, Object>>() {
        });
        Page<SearchSingle> autoPage = new Page<>(page, rows);
        Page<SearchSingle> list = searchSingleMapper.selectByAnnotatePage(autoPage, map);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON xmlPage(int page, int rows, String params) {
        //解析参数
        JSONObject jsonObject = JSON.parseObject(params);
        String birth = jsonObject.getString("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");
        Date birthDate = null;
        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (addTimeRange != null) {
            String begin = addTimeRange.getString(0);
            String end = addTimeRange.getString(1);
            if (StringUtils.isNotEmpty(birth)) {
                birthDate = DateUtil.parse(birth, "yyyy-MM-dd");
            }
            if (StringUtils.isNotEmpty(begin)) {
                addTimeBegin = DateUtil.parse(begin, "yyyy-MM-dd HH:mm:ss");
            }
            if (StringUtils.isNotEmpty(end)) {
                addTimeEnd = DateUtil.parse(end, "yyyy-MM-dd HH:mm:ss");
            }
        }

        Page<SearchSingle> autoPage = new Page<>(page, rows);
        Page<SearchSingle> list = searchSingleMapper.selectByXmlPage(autoPage, birthDate, name, code, type, addTimeBegin, addTimeEnd);
        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON paramJsonPage(String userId, int page,
                                    int rows, String type, String code, String name, String[] addTime, String birthDate, int age) {

        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (ArrayUtils.isEmpty(addTime)) {
            addTimeBegin = null;
            addTimeEnd = null;
        } else {
            addTimeBegin = StringUtils.isNotEmpty(addTime[0]) ? DateUtil.parse(addTime[0], "yyyy-MM-dd") : null;
            addTimeEnd = StringUtils.isNotEmpty(addTime[1]) ? DateUtil.parse(addTime[1], "yyyy-MM-dd") : null;
        }

        Date birthDay = null;
        if(StringUtils.isNotEmpty(birthDate)){
            birthDay = DateUtil.parse(birthDate, "yyyy-MM-dd");
        }

        QueryWrapper<SearchSingle> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");
        queryWrapper.eq(ObjectUtils.isNotEmpty(birthDay), "BIRTH_DATE", birthDay);
        queryWrapper.eq(StringUtils.isNotEmpty(type), "TYPE", type);
        queryWrapper.like(StringUtils.isNotEmpty(code), "CODE", code);
        queryWrapper.eq(StringUtils.isNotEmpty(name), "NAME", name);
        queryWrapper.eq("age", age);
        queryWrapper.between(ObjectUtils.isNotEmpty(addTimeBegin), "ADD_TIME", addTimeBegin, addTimeEnd);
        queryWrapper.orderByDesc("add_time");

        Page<SearchSingle> autoPage = new Page<>(page, rows);
        Page<SearchSingle> list = searchSingleMapper.selectPage(autoPage, queryWrapper);

        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }

    @Override
    public ResultJSON paramStringPage(String userId, String params) {
        JSONObject jsonObject = JSON.parseObject(params);
        Date birthDate = jsonObject.getDate("birthDate");
        String type = jsonObject.getString("type");
        String code = jsonObject.getString("code");
        String name = jsonObject.getString("name");
        JSONArray addTimeRange = jsonObject.getJSONArray("addTime");
        int page = jsonObject.getInteger("page");
        int rows = jsonObject.getInteger("rows");


        Date addTimeBegin = null;
        Date addTimeEnd = null;
        if (addTimeRange != null) {
            addTimeBegin = addTimeRange.getDate(0);
            addTimeEnd = addTimeRange.getDate(1);
        }


        Page<SearchSingle> autoPage = new Page<>(page, rows);
        QueryWrapper<SearchSingle> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("cancel_flag", "0");
        queryWrapper.eq(ObjectUtils.isNotEmpty(birthDate), "BIRTH_DATE", birthDate);
        queryWrapper.eq(StringUtils.isNotEmpty(type), "TYPE", type);
        queryWrapper.like(StringUtils.isNotEmpty(code), "CODE", code);
        queryWrapper.eq(StringUtils.isNotEmpty(name), "NAME", name);
        queryWrapper.between(ObjectUtils.isNotEmpty(addTimeBegin), "ADD_TIME", addTimeBegin, addTimeEnd);
        queryWrapper.orderByDesc("add_time");
        Page<SearchSingle> list = searchSingleMapper.selectPage(autoPage, queryWrapper);

        resultJSON = JSONTools.toResultJSON(list);
        return resultJSON;
    }


}
